@import "shadow.scss";
@media screen {
/*Rock*/
    #rock {
    /* Default (small) screens */
        * {
            box-sizing: content-box;
        }
        body {
            background: url("gradient.png") fixed repeat-x 0% 0%, #100;
            color: #ffffff;
            text-align: center;
            font-size: 1.5em;
            font-family: sans-serif;
        }

        main, figure {
            margin-left: 0em;
            padding-left: 0em;
        }

        h1 {
            margin: 0em;
            font-size: 1.2em;
        }

        h2 {
            font-size: 1em;
        }
        figure {
            text-align: center;
            border: none;
            padding: 0em;
            margin-left: 0em;
            margin-right: 0em;
            max-width: 99%;
        }
        .cominavbox, .cominavbox li {
            display: inline-block;
            padding: 0em;
        }

        * + * {
            margin-top: 0.5em
        }

        /*TODO: Fix the skip link hiding method*/
        #skippy {
            text-align: left;
        }
        #skippy a, #skippy a:hover, #skippy a:visited {
        position:absolute;
        left:-10000px;
        top:auto;
        width:1px;
        height:1px;
        overflow:hidden;
        }

        #skippy a:active, #skippy a:focus {
          position: static;
          height: auto;
          width: auto;
          font-size: 1em;
          margin-top: 0em;
          color: #ffffff;
        }

        nav li {
            display: inline-block;
            margin: 0em;
        }
        
        li + li {
            margin-left: 1em;
        }
        
        ol li {
            margin-left: 0em
        }

        #commentary, #transcript {
            text-align: left;
        }

        .statline {
            font-weight: bold;
        }

        a:link {
            color: #7c7cff;
            text-decoration: underline
        }

        a:visited {
            color: #b97cff;
        }

        a:hover, a:focus, a:active {
            color: #ffffff;
        }

        footer p {
            margin-left: 0em;
            text-align: left;
        }

        .archive {
            display: inline-block;
            vertical-align: top;
            text-align: left;
        }

        nav li, main div, .archive {
            background: #000;
            border: solid #3413ff thick;
            padding: 0.5em;
        }
        
        figure img {
            border: solid #3413ff thick;
        }
        
        figcaption {
            margin: 1em 1em 0em 1em;
            background: #000;
            border: solid #3413ff medium;
            padding: 0.5em;
        }

        #commentary, #transcript {
            padding-top: .5em;
            padding-bottom: .5em;
            padding-left: 1.2em;
            padding-right: 1.4em;
        }

        img, embed, object, video {
            max-width: 100%;
        }

        .archive li {
            margin-top: 1em;
        }
        
        .char {
            text-align: left;
            dt:after {
                content: ":"
            };
            dd:after {
                content: "\A"; white-space: pre;
            };
            dd {
                margin-left: 0em;
            };
            dt, dd {
                display: inline;
                white-space: pre;
            };
            dl {
                font-size: 0.9em;
            };
            img {
                margin: 1em;
            };
            .chartext {
                border: none;
                -webkit-box-shadow: none;
                -moz-box-shadow: none;
                box-shadow: none;
                padding: none;
                margin: none;
            }
        }
        
        .intro {
            border: none;
            margin: 0em;
            padding: 0em;
        }

    /*Medium screens*/

        @media screen and (min-width: 1024px) {
            body {
                margin-left: 1em;
            }
            main div, main section, nav li {
                @include shadow(0em, 0em, 0.5em, 0.5em, #fff);
            }
            figure {
                padding: 1em;
                margin: 0em 0em 0em 1em;
                & img {
                    @include shadow(0em, 0em, 1em, 0.5em, #ffb917);
                }
            }
            
            figcaption {
                @include shadow(0em, 0em, 0.5em, 0.5em, #ffb917);
            }

            .cominavbox li {
                margin-left: 1em;
                margin-right: 1em;
                margin-bottom: 0em;
            }
            
            .cominavbox {
                margin: 1em;
            }

            figure + .cominavbox {
                margin-top: 0em;
                margin-bottom: 0em;
            }

            h1 {
                font-size: 1.4em;
            }

            h2 {
                font-size: 1.2em;
                background: url("starw.png") no-repeat top left, #000;
                background-size: contain;
                padding-left: 2em;
            }
            
            h3 {
                font-size: 1em;
            }

            nav li {
                padding: 0.5em;
            }

            .statline {
                font-size: 0.8em;
            }

            footer p {
                font-size: 0.7em;
            }

            .archive {
                margin: 1em;
                padding: 1em;
                & h2 {
                    margin: 0em 0em 1em 0em;
                }
            }

            main div, main section {
                margin: 2em;
                padding: .5em 1.4em .5em 1.2em;
                width: 80%;
            }
            
            .main {
                padding: 0.5em;
                margin: 1em auto 1em auto;
                width: 50%;
                & p {
                    margin-left: 0em;
                }
            }
            
            .intro {
                text-align: left;
                background: none;
                -webkit-box-shadow: none;
                -moz-box-shadow: none;
                box-shadow: none;
                & h2 {
                    margin-bottom: 0.5em;
                };
                & img {
                    display: inline;
                };
                & .author {
                    font-size: 0.8em;
                    font-weight: bold;
                }
                & .desc {
                    font-weight: bold;
                }
            }
            
            .main, .intro {
                text-align: left;
                & p {
                  text-align: left;
                  margin: 1em;
                }
            }
            
            .char {                
                img {
                    margin: 0em 1em 1em 0em
                }
                .chartext {
                    margin: 0em;
                    text-align: left
                }
                .chartext, img {
                    display: inline-block;
                    vertical-align: top;
                    max-width: 50%;
                }
            }

            .chartext {
                border: none;
                -webkit-box-shadow: none;
                -moz-box-shadow: none;
                box-shadow: none;
                padding: none;
                margin: none;
            }

        }
    }
}
